cfn-lint-serverless
===================

Ruleset for [cfn-lint](https://github.com/aws-cloudformation/cfn-lint) for serverless applications.

Installation
------------

```bash
pip install cfn-lint cfn-lint-serverless
```

Usage
-----

```bash
cfn-lint template.yaml -a cfn_lint_serverless.rules
```